@@ -7,7 +7,7 @@ from grpc_health.v1 import health, health_pb2_grpc
 from grpc_health.v1.health_pb2 import _HEALTH, HealthCheckResponse
 from delphai_utils.logging import logging
 from google.protobuf.descriptor import FileDescriptor
-from gateway import start_gateway
+from delphai_utils.gateway import start_gateway
 import signal
 
 shutdown_event = asyncio.Event()
